# SixAds data science package

This package contains functions that are used in various six ads data science projects.

# Installation

In an anaconda prompt type (windows users):

```console
curl https://bootstrap.pypa.io/get-pip.py -o get-pip.py
python get-pip.py
pip install SixAdsDS
```

# Modules

## Clean_text

Functions to clean and preprocess textual data. 

## Sql_utility 

Functions to read, write and alter information in the database.

## Utility

Utility functions.